@@ -1,20 +1,16 @@
-import sys
 import errno
 import logging
 import os
 import shutil
 import stat
+import sys
 
 import nanotime
 from shortuuid import uuid
 
 from dvc.exceptions import DvcException
-from dvc.scm.tree import is_working_tree
 from dvc.system import System
 from dvc.utils import dict_md5
-from dvc.utils import fspath
-from dvc.utils import fspath_py35
-
 
 logger = logging.getLogger(__name__)
 
@@ -36,27 +32,25 @@ def get_inode(path):
 
 def get_mtime_and_size(path, tree):
 
-    if os.path.isdir(fspath_py35(path)):
-        assert is_working_tree(tree)
-
+    if tree.isdir(path):
         size = 0
         files_mtimes = {}
         for file_path in tree.walk_files(path):
             try:
-                stat = os.stat(file_path)
+                stats = tree.stat(file_path)
             except OSError as exc:
                 # NOTE: broken symlink case.
                 if exc.errno != errno.ENOENT:
                     raise
                 continue
-            size += stat.st_size
-            files_mtimes[file_path] = stat.st_mtime
+            size += stats.st_size
+            files_mtimes[file_path] = stats.st_mtime
 
         # We track file changes and moves, which cannot be detected with simply
         # max(mtime(f) for f in non_ignored_files)
         mtime = dict_md5(files_mtimes)
     else:
-        base_stat = os.stat(fspath_py35(path))
+        base_stat = tree.stat(path)
         size = base_stat.st_size
         mtime = base_stat.st_mtime
         mtime = int(nanotime.timestamp(mtime))
@@ -75,8 +69,8 @@ class BasePathNotInCheckedPathException(DvcException):
 
 
 def contains_symlink_up_to(path, base_path):
-    base_path = fspath(base_path)
-    path = fspath(path)
+    base_path = os.fspath(base_path)
+    path = os.fspath(path)
 
     if base_path not in path:
         raise BasePathNotInCheckedPathException(path, base_path)
@@ -98,14 +92,12 @@ def move(src, dst, mode=None):
     of data is happening.
     """
 
-    src = fspath(src)
-    dst = fspath(dst)
-
     dst = os.path.abspath(dst)
-    tmp = "{}.{}".format(dst, uuid())
+    tmp = f"{dst}.{uuid()}"
 
     if os.path.islink(src):
-        shutil.copy(os.readlink(src), tmp)
+        # readlink does not accept path-like obj for Windows in Python <3.8
+        shutil.copy(os.readlink(os.fspath(src)), tmp)
         os.unlink(src)
     else:
         shutil.move(src, tmp)
@@ -116,7 +108,7 @@ def move(src, dst, mode=None):
     shutil.move(tmp, dst)
 
 
-def _chmod(func, p, excinfo):
+def _chmod(func, p, excinfo):  # pylint: disable=unused-argument
     perm = os.lstat(p).st_mode
     perm |= stat.S_IWRITE
 
@@ -140,7 +132,6 @@ def _unlink(path, onerror):
 def remove(path):
     logger.debug("Removing '%s'", path)
 
-    path = fspath_py35(path)
     try:
         if os.path.isdir(path):
             shutil.rmtree(path, onerror=_chmod)
@@ -155,7 +146,7 @@ def path_isin(child, parent):
     """Check if given `child` path is inside `parent`."""
 
     def normalize_path(path):
-        return os.path.normpath(fspath_py35(path))
+        return os.path.normpath(path)
 
     parent = os.path.join(normalize_path(parent), "")
     child = normalize_path(child)
@@ -163,8 +154,6 @@ def path_isin(child, parent):
 
 
 def makedirs(path, exist_ok=False, mode=None):
-    path = fspath_py35(path)
-
     if mode is None:
         os.makedirs(path, exist_ok=exist_ok)
         return
@@ -181,12 +170,7 @@ def makedirs(path, exist_ok=False, mode=None):
 
 def copyfile(src, dest, no_progress_bar=False, name=None):
     """Copy file with progress bar"""
-    from dvc.exceptions import DvcException
     from dvc.progress import Tqdm
-    from dvc.system import System
-
-    src = fspath_py35(src)
-    dest = fspath_py35(dest)
 
     name = name if name else os.path.basename(dest)
     total = os.stat(src).st_size
@@ -213,7 +197,13 @@ def copyfile(src, dest, no_progress_bar=False, name=None):
                     fdest_wrapped.write(buf)
 
 
+def copy_fobj_to_file(fsrc, dest):
+    """Copy contents of open file object to destination path."""
+    with open(dest, "wb+") as fdest:
+        shutil.copyfileobj(fsrc, fdest)
+
+
 def walk_files(directory):
-    for root, _, files in os.walk(fspath(directory)):
+    for root, _, files in os.walk(directory):
         for f in files:
             yield os.path.join(root, f)
